/*
 * dict.h -- simple dictionaries
 *
 * Copyright 2007-2008 Red Hat, Inc.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author(s): Peter Jones <pjones@redhat.com>
 */

#ifndef NASH_PRIV_DICT_H
#define NASH_PRIV_DICT_H 1

#ifdef _GNU_SOURCE
#define _GNU_SOURCE_DEFINED
#else
#define _GNU_SOURCE 1
#endif

#include "list.h"

struct nash_dict;
struct nash_dict_iter;

extern struct nash_dict *nash_dict_new(nash_hash_item_func hash,
                                nash_cmp_item_func cmp);
extern void nash_dict_free(struct nash_dict *dict);
extern int nash_dict_get_kv(struct nash_dict *dict, void *key,
        void **k, void **v);
extern void *nash_dict_get(struct nash_dict *dict, void *key);
extern int nash_dict_add(struct nash_dict *dict, void *key, void *value);
extern int nash_dict_del(struct nash_dict *dict, void *key);
extern int nash_dict_update(struct nash_dict *dict, uint32_t oldhash,
        uint32_t newhash, void *key, void *value);
extern void nash_dict_items_end(struct nash_dict_iter *iter);
extern struct nash_dict_iter *nash_dict_items_next(struct nash_dict *dict,
        struct nash_dict_iter *iter, void **key, void **value);

#ifndef _GNU_SOURCE_DEFINED
#undef _GNU_SOURCE
#else
#undef _GNU_SOURCE_DEFINED
#endif

#endif /* NASH_PRIV_DICT_H */
/*
 * vim:ts=8:sw=4:sts=4:et
 */
